Automatically detect enter and exit from the chamber based on the notefile. Returns the start and end times for two participants.
Source:R/processing.R
detect_start_end.RdAutomatically detect enter and exit from the chamber based on the notefile. Returns the start and end times for two participants.
Value
list - A list of two elements ("1" and "2"), each containing a tuple (start, end) time. Returns NA if not possible to find start or end time.
Examples
notes_path <- system.file("extdata", "note.txt", package = "wrictools")
detect_start_end(notes_path)
#> $`1`
#> $`1`[[1]]
#> [1] NA
#>
#> $`1`[[2]]
#> [1] NA
#>
#>
#> $`2`
#> $`2`[[1]]
#> [1] NA
#>
#> $`2`[[2]]
#> [1] NA
#>
#>